summaryrefslogtreecommitdiff
path: root/sc/source/ui/attrdlg/tabpages.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'sc/source/ui/attrdlg/tabpages.cxx')
-rw-r--r--sc/source/ui/attrdlg/tabpages.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/sc/source/ui/attrdlg/tabpages.cxx b/sc/source/ui/attrdlg/tabpages.cxx
index 88814f3fdfb1..2884663d4df0 100644
--- a/sc/source/ui/attrdlg/tabpages.cxx
+++ b/sc/source/ui/attrdlg/tabpages.cxx
@@ -79,9 +79,9 @@ void ScTabPageProtection::Reset( const SfxItemSet* rCoreAttrs )
(const SfxPoolItem**)&pProtAttr );
// Is this a Default-Item?
- if ( eItemState == SFX_ITEM_DEFAULT )
+ if ( eItemState == SfxItemState::DEFAULT )
pProtAttr = (const ScProtectionAttr*)&(rCoreAttrs->Get(nWhich));
// At SFX_ITEM_DONTCARE let to 0
bTriEnabled = ( pProtAttr == NULL ); // TriState, when DontCare
bDontCare = bTriEnabled;
@@ -136,7 +136,7 @@ bool ScTabPageProtection::FillItemSet( SfxItemSet* rCoreAttrs )
if ( bAttrsChanged )
rCoreAttrs->Put( aProtAttr );
- else if ( eItemState == SFX_ITEM_DEFAULT )
+ else if ( eItemState == SfxItemState::DEFAULT )
rCoreAttrs->ClearItem( nWhich );
return bAttrsChanged;
@@ -79,9 +79,9 @@ void ScTabPageProtection::Reset( const SfxItemSet* rCoreAttrs )
pProtAttr = (const ScProtectionAttr*)&(rCoreAttrs->Get(nWhich));
- // At SFX_ITEM_DONTCARE let to 0
+ // At SfxItemState::DONTCARE let to 0
bTriEnabled = ( pProtAttr == NULL ); // TriState, when DontCare
bDontCare = bTriEnabled;